# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/proto/direction.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/proto/direction.proto',
  package='apollo.common',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/common/proto/direction.proto\x12\rapollo.common*q\n\tDirection\x12\x08\n\x04\x45\x41ST\x10\x00\x12\x08\n\x04WEST\x10\x01\x12\t\n\x05SOUTH\x10\x02\x12\t\n\x05NORTH\x10\x03\x12\r\n\tNORTHEAST\x10\x04\x12\r\n\tSOUTHEAST\x10\x05\x12\r\n\tSOUTHWEST\x10\x06\x12\r\n\tNORTHWEST\x10\x07'
)

_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='apollo.common.Direction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EAST', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOUTH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORTH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORTHEAST', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOUTHEAST', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOUTHWEST', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORTHWEST', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=55,
  serialized_end=168,
)
_sym_db.RegisterEnumDescriptor(_DIRECTION)

Direction = enum_type_wrapper.EnumTypeWrapper(_DIRECTION)
EAST = 0
WEST = 1
SOUTH = 2
NORTH = 3
NORTHEAST = 4
SOUTHEAST = 5
SOUTHWEST = 6
NORTHWEST = 7


DESCRIPTOR.enum_types_by_name['Direction'] = _DIRECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/gnss/proto/gnss_best_pose.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/gnss/proto/gnss_best_pose.proto',
  package='apollo.drivers.gnss',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/modules/drivers/gnss/proto/gnss_best_pose.proto\x12\x13\x61pollo.drivers.gnss\x1a!modules/common/proto/header.proto\"\xaa\x05\n\x0cGnssBestPose\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x18\n\x10measurement_time\x18\x02 \x01(\x01\x12\x37\n\nsol_status\x18\x03 \x01(\x0e\x32#.apollo.drivers.gnss.SolutionStatus\x12\x33\n\x08sol_type\x18\x04 \x01(\x0e\x32!.apollo.drivers.gnss.SolutionType\x12\x10\n\x08latitude\x18\x05 \x01(\x01\x12\x11\n\tlongitude\x18\x06 \x01(\x01\x12\x12\n\nheight_msl\x18\x07 \x01(\x01\x12\x12\n\nundulation\x18\x08 \x01(\x02\x12.\n\x08\x64\x61tum_id\x18\t \x01(\x0e\x32\x1c.apollo.drivers.gnss.DatumId\x12\x18\n\x10latitude_std_dev\x18\n \x01(\x02\x12\x19\n\x11longitude_std_dev\x18\x0b \x01(\x02\x12\x16\n\x0eheight_std_dev\x18\x0c \x01(\x02\x12\x17\n\x0f\x62\x61se_station_id\x18\r \x01(\x0c\x12\x18\n\x10\x64ifferential_age\x18\x0e \x01(\x02\x12\x14\n\x0csolution_age\x18\x0f \x01(\x02\x12\x18\n\x10num_sats_tracked\x18\x10 \x01(\r\x12\x1c\n\x14num_sats_in_solution\x18\x11 \x01(\r\x12\x13\n\x0bnum_sats_l1\x18\x12 \x01(\r\x12\x16\n\x0enum_sats_multi\x18\x13 \x01(\r\x12\x10\n\x08reserved\x18\x14 \x01(\r\x12 \n\x18\x65xtended_solution_status\x18\x15 \x01(\r\x12 \n\x18galileo_beidou_used_mask\x18\x16 \x01(\r\x12\x1d\n\x15gps_glonass_used_mask\x18\x17 \x01(\r*\x90\x02\n\x0eSolutionStatus\x12\x10\n\x0cSOL_COMPUTED\x10\x00\x12\x14\n\x10INSUFFICIENT_OBS\x10\x01\x12\x12\n\x0eNO_CONVERGENCE\x10\x02\x12\x0f\n\x0bSINGULARITY\x10\x03\x12\r\n\tCOV_TRACE\x10\x04\x12\r\n\tTEST_DIST\x10\x05\x12\x0e\n\nCOLD_START\x10\x06\x12\r\n\tV_H_LIMIT\x10\x07\x12\x0c\n\x08VARIANCE\x10\x08\x12\r\n\tRESIDUALS\x10\t\x12\x15\n\x11INTEGRITY_WARNING\x10\r\x12\x0b\n\x07PENDING\x10\x12\x12\x0f\n\x0bINVALID_FIX\x10\x13\x12\x10\n\x0cUNAUTHORIZED\x10\x14\x12\x10\n\x0cINVALID_RATE\x10\x16*\x9f\x04\n\x0cSolutionType\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08\x46IXEDPOS\x10\x01\x12\x0f\n\x0b\x46IXEDHEIGHT\x10\x02\x12\r\n\tFLOATCONV\x10\x04\x12\x0c\n\x08WIDELANE\x10\x05\x12\x0e\n\nNARROWLANE\x10\x06\x12\x14\n\x10\x44OPPLER_VELOCITY\x10\x08\x12\n\n\x06SINGLE\x10\x10\x12\x0b\n\x07PSRDIFF\x10\x11\x12\x08\n\x04WAAS\x10\x12\x12\x0e\n\nPROPOGATED\x10\x13\x12\x0c\n\x08OMNISTAR\x10\x14\x12\x0c\n\x08L1_FLOAT\x10 \x12\x12\n\x0eIONOFREE_FLOAT\x10!\x12\x10\n\x0cNARROW_FLOAT\x10\"\x12\n\n\x06L1_INT\x10\x30\x12\x0c\n\x08WIDE_INT\x10\x31\x12\x0e\n\nNARROW_INT\x10\x32\x12\x12\n\x0eRTK_DIRECT_INS\x10\x33\x12\x0c\n\x08INS_SBAS\x10\x34\x12\r\n\tINS_PSRSP\x10\x35\x12\x0f\n\x0bINS_PSRDIFF\x10\x36\x12\x10\n\x0cINS_RTKFLOAT\x10\x37\x12\x10\n\x0cINS_RTKFIXED\x10\x38\x12\x10\n\x0cINS_OMNISTAR\x10\x39\x12\x13\n\x0fINS_OMNISTAR_HP\x10:\x12\x13\n\x0fINS_OMNISTAR_XP\x10;\x12\x0f\n\x0bOMNISTAR_HP\x10@\x12\x0f\n\x0bOMNISTAR_XP\x10\x41\x12\x12\n\x0ePPP_CONVERGING\x10\x44\x12\x07\n\x03PPP\x10\x45\x12\x16\n\x12INS_PPP_CONVERGING\x10I\x12\x0b\n\x07INS_PPP\x10J*\x14\n\x07\x44\x61tumId\x12\t\n\x05WGS84\x10='
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])

_SOLUTIONSTATUS = _descriptor.EnumDescriptor(
  name='SolutionStatus',
  full_name='apollo.drivers.gnss.SolutionStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SOL_COMPUTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INSUFFICIENT_OBS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_CONVERGENCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINGULARITY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COV_TRACE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEST_DIST', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLD_START', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='V_H_LIMIT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VARIANCE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESIDUALS', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTEGRITY_WARNING', index=10, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=11, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FIX', index=12, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNAUTHORIZED', index=13, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_RATE', index=14, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=793,
  serialized_end=1065,
)
_sym_db.RegisterEnumDescriptor(_SOLUTIONSTATUS)

SolutionStatus = enum_type_wrapper.EnumTypeWrapper(_SOLUTIONSTATUS)
_SOLUTIONTYPE = _descriptor.EnumDescriptor(
  name='SolutionType',
  full_name='apollo.drivers.gnss.SolutionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIXEDPOS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIXEDHEIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOATCONV', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIDELANE', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROWLANE', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOPPLER_VELOCITY', index=6, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINGLE', index=7, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PSRDIFF', index=8, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAAS', index=9, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROPOGATED', index=10, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OMNISTAR', index=11, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='L1_FLOAT', index=12, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IONOFREE_FLOAT', index=13, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROW_FLOAT', index=14, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='L1_INT', index=15, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIDE_INT', index=16, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NARROW_INT', index=17, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RTK_DIRECT_INS', index=18, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_SBAS', index=19, number=52,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_PSRSP', index=20, number=53,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_PSRDIFF', index=21, number=54,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_RTKFLOAT', index=22, number=55,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_RTKFIXED', index=23, number=56,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_OMNISTAR', index=24, number=57,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_OMNISTAR_HP', index=25, number=58,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_OMNISTAR_XP', index=26, number=59,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OMNISTAR_HP', index=27, number=64,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OMNISTAR_XP', index=28, number=65,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PPP_CONVERGING', index=29, number=68,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PPP', index=30, number=69,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_PPP_CONVERGING', index=31, number=73,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INS_PPP', index=32, number=74,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1068,
  serialized_end=1611,
)
_sym_db.RegisterEnumDescriptor(_SOLUTIONTYPE)

SolutionType = enum_type_wrapper.EnumTypeWrapper(_SOLUTIONTYPE)
_DATUMID = _descriptor.EnumDescriptor(
  name='DatumId',
  full_name='apollo.drivers.gnss.DatumId',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WGS84', index=0, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1613,
  serialized_end=1633,
)
_sym_db.RegisterEnumDescriptor(_DATUMID)

DatumId = enum_type_wrapper.EnumTypeWrapper(_DATUMID)
SOL_COMPUTED = 0
INSUFFICIENT_OBS = 1
NO_CONVERGENCE = 2
SINGULARITY = 3
COV_TRACE = 4
TEST_DIST = 5
COLD_START = 6
V_H_LIMIT = 7
VARIANCE = 8
RESIDUALS = 9
INTEGRITY_WARNING = 13
PENDING = 18
INVALID_FIX = 19
UNAUTHORIZED = 20
INVALID_RATE = 22
NONE = 0
FIXEDPOS = 1
FIXEDHEIGHT = 2
FLOATCONV = 4
WIDELANE = 5
NARROWLANE = 6
DOPPLER_VELOCITY = 8
SINGLE = 16
PSRDIFF = 17
WAAS = 18
PROPOGATED = 19
OMNISTAR = 20
L1_FLOAT = 32
IONOFREE_FLOAT = 33
NARROW_FLOAT = 34
L1_INT = 48
WIDE_INT = 49
NARROW_INT = 50
RTK_DIRECT_INS = 51
INS_SBAS = 52
INS_PSRSP = 53
INS_PSRDIFF = 54
INS_RTKFLOAT = 55
INS_RTKFIXED = 56
INS_OMNISTAR = 57
INS_OMNISTAR_HP = 58
INS_OMNISTAR_XP = 59
OMNISTAR_HP = 64
OMNISTAR_XP = 65
PPP_CONVERGING = 68
PPP = 69
INS_PPP_CONVERGING = 73
INS_PPP = 74
WGS84 = 61



_GNSSBESTPOSE = _descriptor.Descriptor(
  name='GnssBestPose',
  full_name='apollo.drivers.gnss.GnssBestPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.gnss.GnssBestPose.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_time', full_name='apollo.drivers.gnss.GnssBestPose.measurement_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sol_status', full_name='apollo.drivers.gnss.GnssBestPose.sol_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sol_type', full_name='apollo.drivers.gnss.GnssBestPose.sol_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='apollo.drivers.gnss.GnssBestPose.latitude', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='apollo.drivers.gnss.GnssBestPose.longitude', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height_msl', full_name='apollo.drivers.gnss.GnssBestPose.height_msl', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undulation', full_name='apollo.drivers.gnss.GnssBestPose.undulation', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datum_id', full_name='apollo.drivers.gnss.GnssBestPose.datum_id', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=61,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude_std_dev', full_name='apollo.drivers.gnss.GnssBestPose.latitude_std_dev', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude_std_dev', full_name='apollo.drivers.gnss.GnssBestPose.longitude_std_dev', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height_std_dev', full_name='apollo.drivers.gnss.GnssBestPose.height_std_dev', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_station_id', full_name='apollo.drivers.gnss.GnssBestPose.base_station_id', index=12,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='differential_age', full_name='apollo.drivers.gnss.GnssBestPose.differential_age', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solution_age', full_name='apollo.drivers.gnss.GnssBestPose.solution_age', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_sats_tracked', full_name='apollo.drivers.gnss.GnssBestPose.num_sats_tracked', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_sats_in_solution', full_name='apollo.drivers.gnss.GnssBestPose.num_sats_in_solution', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_sats_l1', full_name='apollo.drivers.gnss.GnssBestPose.num_sats_l1', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_sats_multi', full_name='apollo.drivers.gnss.GnssBestPose.num_sats_multi', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved', full_name='apollo.drivers.gnss.GnssBestPose.reserved', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extended_solution_status', full_name='apollo.drivers.gnss.GnssBestPose.extended_solution_status', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='galileo_beidou_used_mask', full_name='apollo.drivers.gnss.GnssBestPose.galileo_beidou_used_mask', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gps_glonass_used_mask', full_name='apollo.drivers.gnss.GnssBestPose.gps_glonass_used_mask', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=790,
)

_GNSSBESTPOSE.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_GNSSBESTPOSE.fields_by_name['sol_status'].enum_type = _SOLUTIONSTATUS
_GNSSBESTPOSE.fields_by_name['sol_type'].enum_type = _SOLUTIONTYPE
_GNSSBESTPOSE.fields_by_name['datum_id'].enum_type = _DATUMID
DESCRIPTOR.message_types_by_name['GnssBestPose'] = _GNSSBESTPOSE
DESCRIPTOR.enum_types_by_name['SolutionStatus'] = _SOLUTIONSTATUS
DESCRIPTOR.enum_types_by_name['SolutionType'] = _SOLUTIONTYPE
DESCRIPTOR.enum_types_by_name['DatumId'] = _DATUMID
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GnssBestPose = _reflection.GeneratedProtocolMessageType('GnssBestPose', (_message.Message,), {
  'DESCRIPTOR' : _GNSSBESTPOSE,
  '__module__' : 'modules.drivers.gnss.proto.gnss_best_pose_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.GnssBestPose)
  })
_sym_db.RegisterMessage(GnssBestPose)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/prediction/proto/prediction_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.perception.proto import perception_obstacle_pb2 as modules_dot_perception_dot_proto_dot_perception__obstacle__pb2
from modules.prediction.proto import feature_pb2 as modules_dot_prediction_dot_proto_dot_feature__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/prediction/proto/prediction_conf.proto',
  package='apollo.prediction',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.modules/prediction/proto/prediction_conf.proto\x12\x11\x61pollo.prediction\x1a\x32modules/perception/proto/perception_obstacle.proto\x1a&modules/prediction/proto/feature.proto\"\x97\x08\n\x0cObstacleConf\x12\x41\n\robstacle_type\x18\x01 \x01(\x0e\x32*.apollo.perception.PerceptionObstacle.Type\x12S\n\x0fobstacle_status\x18\x02 \x01(\x0e\x32..apollo.prediction.ObstacleConf.ObstacleStatus:\nSTATIONARY\x12\x43\n\rpriority_type\x18\x05 \x01(\x0e\x32,.apollo.prediction.ObstaclePriority.Priority\x12\x45\n\x0e\x65valuator_type\x18\x03 \x01(\x0e\x32-.apollo.prediction.ObstacleConf.EvaluatorType\x12\x45\n\x0epredictor_type\x18\x04 \x01(\x0e\x32-.apollo.prediction.ObstacleConf.PredictorType\"X\n\x0eObstacleStatus\x12\x0b\n\x07ON_LANE\x10\x00\x12\x0c\n\x08OFF_LANE\x10\x01\x12\x0e\n\nSTATIONARY\x10\x03\x12\n\n\x06MOVING\x10\x04\x12\x0f\n\x0bIN_JUNCTION\x10\x05\"\xc0\x02\n\rEvaluatorType\x12\x11\n\rMLP_EVALUATOR\x10\x00\x12\x15\n\rRNN_EVALUATOR\x10\x01\x1a\x02\x08\x01\x12\x12\n\x0e\x43OST_EVALUATOR\x10\x02\x12\x18\n\x14\x43RUISE_MLP_EVALUATOR\x10\x03\x12\x1a\n\x16JUNCTION_MLP_EVALUATOR\x10\x04\x12\x1f\n\x1b\x43YCLIST_KEEP_LANE_EVALUATOR\x10\x05\x12\x1b\n\x17LANE_SCANNING_EVALUATOR\x10\x06\x12$\n PEDESTRIAN_INTERACTION_EVALUATOR\x10\x07\x12\x1a\n\x16JUNCTION_MAP_EVALUATOR\x10\x08\x12\x1e\n\x1aLANE_AGGREGATING_EVALUATOR\x10\t\x12\x1b\n\x17SEMANTIC_LSTM_EVALUATOR\x10\n\"\xfe\x01\n\rPredictorType\x12\x1b\n\x17LANE_SEQUENCE_PREDICTOR\x10\x00\x12\x17\n\x13\x46REE_MOVE_PREDICTOR\x10\x01\x12\x1a\n\x12REGIONAL_PREDICTOR\x10\x02\x1a\x02\x08\x01\x12\x1b\n\x17MOVE_SEQUENCE_PREDICTOR\x10\x03\x12\x13\n\x0f\x45MPTY_PREDICTOR\x10\x04\x12\x19\n\x15SINGLE_LANE_PREDICTOR\x10\x05\x12\x16\n\x12JUNCTION_PREDICTOR\x10\x06\x12\x1b\n\x17\x45XTRAPOLATION_PREDICTOR\x10\x07\x12\x19\n\x15INTERACTION_PREDICTOR\x10\x08\"\xa9\x02\n\tTopicConf\x12\x1f\n\x17\x61\x64\x63\x63ontainer_topic_name\x18\x01 \x01(\t\x12\x1c\n\x14\x63ontainer_topic_name\x18\x02 \x01(\t\x12\x1c\n\x14\x65valuator_topic_name\x18\x03 \x01(\t\x12\x1a\n\x12localization_topic\x18\x04 \x01(\t\x12!\n\x19perception_obstacle_topic\x18\x05 \x01(\t\x12\'\n\x1fperception_obstacles_topic_name\x18\x06 \x01(\t\x12!\n\x19planning_trajectory_topic\x18\x07 \x01(\t\x12\x18\n\x10prediction_topic\x18\x08 \x01(\t\x12\x1a\n\x12storytelling_topic\x18\t \x01(\t\"z\n\x0ePredictionConf\x12\x30\n\ntopic_conf\x18\x01 \x01(\x0b\x32\x1c.apollo.prediction.TopicConf\x12\x36\n\robstacle_conf\x18\x02 \x03(\x0b\x32\x1f.apollo.prediction.ObstacleConf'
  ,
  dependencies=[modules_dot_perception_dot_proto_dot_perception__obstacle__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_feature__pb2.DESCRIPTOR,])



_OBSTACLECONF_OBSTACLESTATUS = _descriptor.EnumDescriptor(
  name='ObstacleStatus',
  full_name='apollo.prediction.ObstacleConf.ObstacleStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ON_LANE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFF_LANE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATIONARY', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOVING', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN_JUNCTION', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=541,
  serialized_end=629,
)
_sym_db.RegisterEnumDescriptor(_OBSTACLECONF_OBSTACLESTATUS)

_OBSTACLECONF_EVALUATORTYPE = _descriptor.EnumDescriptor(
  name='EvaluatorType',
  full_name='apollo.prediction.ObstacleConf.EvaluatorType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MLP_EVALUATOR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RNN_EVALUATOR', index=1, number=1,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COST_EVALUATOR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUISE_MLP_EVALUATOR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JUNCTION_MLP_EVALUATOR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CYCLIST_KEEP_LANE_EVALUATOR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LANE_SCANNING_EVALUATOR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN_INTERACTION_EVALUATOR', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JUNCTION_MAP_EVALUATOR', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LANE_AGGREGATING_EVALUATOR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEMANTIC_LSTM_EVALUATOR', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=632,
  serialized_end=952,
)
_sym_db.RegisterEnumDescriptor(_OBSTACLECONF_EVALUATORTYPE)

_OBSTACLECONF_PREDICTORTYPE = _descriptor.EnumDescriptor(
  name='PredictorType',
  full_name='apollo.prediction.ObstacleConf.PredictorType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LANE_SEQUENCE_PREDICTOR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FREE_MOVE_PREDICTOR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REGIONAL_PREDICTOR', index=2, number=2,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOVE_SEQUENCE_PREDICTOR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMPTY_PREDICTOR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SINGLE_LANE_PREDICTOR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JUNCTION_PREDICTOR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXTRAPOLATION_PREDICTOR', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERACTION_PREDICTOR', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=955,
  serialized_end=1209,
)
_sym_db.RegisterEnumDescriptor(_OBSTACLECONF_PREDICTORTYPE)


_OBSTACLECONF = _descriptor.Descriptor(
  name='ObstacleConf',
  full_name='apollo.prediction.ObstacleConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obstacle_type', full_name='apollo.prediction.ObstacleConf.obstacle_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_status', full_name='apollo.prediction.ObstacleConf.obstacle_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority_type', full_name='apollo.prediction.ObstacleConf.priority_type', index=2,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evaluator_type', full_name='apollo.prediction.ObstacleConf.evaluator_type', index=3,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predictor_type', full_name='apollo.prediction.ObstacleConf.predictor_type', index=4,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBSTACLECONF_OBSTACLESTATUS,
    _OBSTACLECONF_EVALUATORTYPE,
    _OBSTACLECONF_PREDICTORTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=1209,
)


_TOPICCONF = _descriptor.Descriptor(
  name='TopicConf',
  full_name='apollo.prediction.TopicConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adccontainer_topic_name', full_name='apollo.prediction.TopicConf.adccontainer_topic_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='container_topic_name', full_name='apollo.prediction.TopicConf.container_topic_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evaluator_topic_name', full_name='apollo.prediction.TopicConf.evaluator_topic_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization_topic', full_name='apollo.prediction.TopicConf.localization_topic', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perception_obstacle_topic', full_name='apollo.prediction.TopicConf.perception_obstacle_topic', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perception_obstacles_topic_name', full_name='apollo.prediction.TopicConf.perception_obstacles_topic_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planning_trajectory_topic', full_name='apollo.prediction.TopicConf.planning_trajectory_topic', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prediction_topic', full_name='apollo.prediction.TopicConf.prediction_topic', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storytelling_topic', full_name='apollo.prediction.TopicConf.storytelling_topic', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1212,
  serialized_end=1509,
)


_PREDICTIONCONF = _descriptor.Descriptor(
  name='PredictionConf',
  full_name='apollo.prediction.PredictionConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic_conf', full_name='apollo.prediction.PredictionConf.topic_conf', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_conf', full_name='apollo.prediction.PredictionConf.obstacle_conf', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1511,
  serialized_end=1633,
)

_OBSTACLECONF.fields_by_name['obstacle_type'].enum_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._PERCEPTIONOBSTACLE_TYPE
_OBSTACLECONF.fields_by_name['obstacle_status'].enum_type = _OBSTACLECONF_OBSTACLESTATUS
_OBSTACLECONF.fields_by_name['priority_type'].enum_type = modules_dot_prediction_dot_proto_dot_feature__pb2._OBSTACLEPRIORITY_PRIORITY
_OBSTACLECONF.fields_by_name['evaluator_type'].enum_type = _OBSTACLECONF_EVALUATORTYPE
_OBSTACLECONF.fields_by_name['predictor_type'].enum_type = _OBSTACLECONF_PREDICTORTYPE
_OBSTACLECONF_OBSTACLESTATUS.containing_type = _OBSTACLECONF
_OBSTACLECONF_EVALUATORTYPE.containing_type = _OBSTACLECONF
_OBSTACLECONF_PREDICTORTYPE.containing_type = _OBSTACLECONF
_PREDICTIONCONF.fields_by_name['topic_conf'].message_type = _TOPICCONF
_PREDICTIONCONF.fields_by_name['obstacle_conf'].message_type = _OBSTACLECONF
DESCRIPTOR.message_types_by_name['ObstacleConf'] = _OBSTACLECONF
DESCRIPTOR.message_types_by_name['TopicConf'] = _TOPICCONF
DESCRIPTOR.message_types_by_name['PredictionConf'] = _PREDICTIONCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObstacleConf = _reflection.GeneratedProtocolMessageType('ObstacleConf', (_message.Message,), {
  'DESCRIPTOR' : _OBSTACLECONF,
  '__module__' : 'modules.prediction.proto.prediction_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.ObstacleConf)
  })
_sym_db.RegisterMessage(ObstacleConf)

TopicConf = _reflection.GeneratedProtocolMessageType('TopicConf', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCONF,
  '__module__' : 'modules.prediction.proto.prediction_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.TopicConf)
  })
_sym_db.RegisterMessage(TopicConf)

PredictionConf = _reflection.GeneratedProtocolMessageType('PredictionConf', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONCONF,
  '__module__' : 'modules.prediction.proto.prediction_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.prediction.PredictionConf)
  })
_sym_db.RegisterMessage(PredictionConf)


_OBSTACLECONF_EVALUATORTYPE.values_by_name["RNN_EVALUATOR"]._options = None
_OBSTACLECONF_PREDICTORTYPE.values_by_name["REGIONAL_PREDICTOR"]._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/proto/pointcloud.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/proto/pointcloud.proto',
  package='apollo.drivers',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/drivers/proto/pointcloud.proto\x12\x0e\x61pollo.drivers\x1a!modules/common/proto/header.proto\"h\n\nPointXYZIT\x12\x0e\n\x01x\x18\x01 \x01(\x02:\x03nan\x12\x0e\n\x01y\x18\x02 \x01(\x02:\x03nan\x12\x0e\n\x01z\x18\x03 \x01(\x02:\x03nan\x12\x14\n\tintensity\x18\x04 \x01(\r:\x01\x30\x12\x14\n\ttimestamp\x18\x05 \x01(\x04:\x01\x30\"\xbb\x01\n\nPointCloud\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x10\n\x08\x66rame_id\x18\x02 \x01(\t\x12\x10\n\x08is_dense\x18\x03 \x01(\x08\x12)\n\x05point\x18\x04 \x03(\x0b\x32\x1a.apollo.drivers.PointXYZIT\x12\x18\n\x10measurement_time\x18\x05 \x01(\x01\x12\r\n\x05width\x18\x06 \x01(\r\x12\x0e\n\x06height\x18\x07 \x01(\r'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_POINTXYZIT = _descriptor.Descriptor(
  name='PointXYZIT',
  full_name='apollo.drivers.PointXYZIT',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.drivers.PointXYZIT.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.drivers.PointXYZIT.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.drivers.PointXYZIT.z', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=(1e10000 * 0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intensity', full_name='apollo.drivers.PointXYZIT.intensity', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.drivers.PointXYZIT.timestamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=197,
)


_POINTCLOUD = _descriptor.Descriptor(
  name='PointCloud',
  full_name='apollo.drivers.PointCloud',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.PointCloud.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.PointCloud.frame_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_dense', full_name='apollo.drivers.PointCloud.is_dense', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point', full_name='apollo.drivers.PointCloud.point', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_time', full_name='apollo.drivers.PointCloud.measurement_time', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.drivers.PointCloud.width', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.drivers.PointCloud.height', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=387,
)

_POINTCLOUD.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_POINTCLOUD.fields_by_name['point'].message_type = _POINTXYZIT
DESCRIPTOR.message_types_by_name['PointXYZIT'] = _POINTXYZIT
DESCRIPTOR.message_types_by_name['PointCloud'] = _POINTCLOUD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PointXYZIT = _reflection.GeneratedProtocolMessageType('PointXYZIT', (_message.Message,), {
  'DESCRIPTOR' : _POINTXYZIT,
  '__module__' : 'modules.drivers.proto.pointcloud_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.PointXYZIT)
  })
_sym_db.RegisterMessage(PointXYZIT)

PointCloud = _reflection.GeneratedProtocolMessageType('PointCloud', (_message.Message,), {
  'DESCRIPTOR' : _POINTCLOUD,
  '__module__' : 'modules.drivers.proto.pointcloud_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.PointCloud)
  })
_sym_db.RegisterMessage(PointCloud)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/lidar/proto/robosense_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/lidar/proto/robosense_config.proto',
  package='apollo.drivers.robosense',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2modules/drivers/lidar/proto/robosense_config.proto\x12\x18\x61pollo.drivers.robosense\"\xbb\x02\n\x06\x43onfig\x12\r\n\x05model\x18\x01 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x02 \x01(\t\x12\n\n\x02ip\x18\x03 \x01(\t\x12\x11\n\tmsop_port\x18\x04 \x01(\r\x12\x12\n\ndifop_port\x18\x05 \x01(\r\x12\x11\n\techo_mode\x18\x06 \x01(\r\x12\x13\n\x0bstart_angle\x18\x08 \x01(\r\x12\x11\n\tend_angle\x18\t \x01(\r\x12\x14\n\x0cmin_distance\x18\n \x01(\r\x12\x14\n\x0cmax_distance\x18\x0b \x01(\r\x12\x11\n\tcut_angle\x18\x0c \x01(\r\x12\x1a\n\x12pointcloud_channel\x18\r \x01(\t\x12\x14\n\x0cscan_channel\x18\x0e \x01(\t\x12\x18\n\x10\x63\x61libration_file\x18\x0f \x01(\t\x12\x17\n\x0fuse_lidar_clock\x18\x10 \x01(\x08'
)




_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='apollo.drivers.robosense.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='apollo.drivers.robosense.Config.model', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='apollo.drivers.robosense.Config.frame_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='apollo.drivers.robosense.Config.ip', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msop_port', full_name='apollo.drivers.robosense.Config.msop_port', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='difop_port', full_name='apollo.drivers.robosense.Config.difop_port', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='echo_mode', full_name='apollo.drivers.robosense.Config.echo_mode', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_angle', full_name='apollo.drivers.robosense.Config.start_angle', index=6,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_angle', full_name='apollo.drivers.robosense.Config.end_angle', index=7,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_distance', full_name='apollo.drivers.robosense.Config.min_distance', index=8,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_distance', full_name='apollo.drivers.robosense.Config.max_distance', index=9,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cut_angle', full_name='apollo.drivers.robosense.Config.cut_angle', index=10,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pointcloud_channel', full_name='apollo.drivers.robosense.Config.pointcloud_channel', index=11,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scan_channel', full_name='apollo.drivers.robosense.Config.scan_channel', index=12,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_file', full_name='apollo.drivers.robosense.Config.calibration_file', index=13,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_lidar_clock', full_name='apollo.drivers.robosense.Config.use_lidar_clock', index=14,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=396,
)

DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'modules.drivers.lidar.proto.robosense_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.robosense.Config)
  })
_sym_db.RegisterMessage(Config)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/math/fem_pos_deviation_smoother_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/math/fem_pos_deviation_smoother_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCmodules/planning/proto/math/fem_pos_deviation_smoother_config.proto\x12\x0f\x61pollo.planning\"\xb6\x05\n\x1d\x46\x65mPosDeviationSmootherConfig\x12-\n\x18weight_fem_pos_deviation\x18\x02 \x01(\x01:\x0b\x31\x30\x30\x30\x30\x30\x30\x30\x30\x30\x30\x12\x1f\n\x14weight_ref_deviation\x18\x03 \x01(\x01:\x01\x31\x12\x1d\n\x12weight_path_length\x18\x04 \x01(\x01:\x01\x31\x12)\n\x1a\x61pply_curvature_constraint\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x32\n%weight_curvature_constraint_slack_var\x18\x06 \x01(\x01:\x03\x31\x30\x30\x12!\n\x14\x63urvature_constraint\x18\x07 \x01(\x01:\x03\x30.2\x12\x16\n\x07use_sqp\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\x18\n\x08sqp_ftol\x18\t \x01(\x01:\x06\x30.0001\x12\x17\n\x08sqp_ctol\x18\n \x01(\x01:\x05\x30.001\x12\x1c\n\x10sqp_pen_max_iter\x18\x0b \x01(\x05:\x02\x31\x30\x12\x1d\n\x10sqp_sub_max_iter\x18\x0c \x01(\x05:\x03\x31\x30\x30\x12\x15\n\x08max_iter\x18\x64 \x01(\x05:\x03\x35\x30\x30\x12\x15\n\ntime_limit\x18\x65 \x01(\x01:\x01\x30\x12\x16\n\x07verbose\x18\x66 \x01(\x08:\x05\x66\x61lse\x12 \n\x12scaled_termination\x18g \x01(\x08:\x04true\x12\x18\n\nwarm_start\x18h \x01(\x08:\x04true\x12\x17\n\x0bprint_level\x18\xc8\x01 \x01(\x05:\x01\x30\x12#\n\x15max_num_of_iterations\x18\xc9\x01 \x01(\x05:\x03\x35\x30\x30\x12)\n\x1c\x61\x63\x63\x65ptable_num_of_iterations\x18\xca\x01 \x01(\x05:\x02\x31\x35\x12\x13\n\x03tol\x18\xcb\x01 \x01(\x01:\x05\x31\x65-08\x12\x1c\n\x0e\x61\x63\x63\x65ptable_tol\x18\xcc\x01 \x01(\x01:\x03\x30.1'
)




_FEMPOSDEVIATIONSMOOTHERCONFIG = _descriptor.Descriptor(
  name='FemPosDeviationSmootherConfig',
  full_name='apollo.planning.FemPosDeviationSmootherConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight_fem_pos_deviation', full_name='apollo.planning.FemPosDeviationSmootherConfig.weight_fem_pos_deviation', index=0,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(10000000000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_ref_deviation', full_name='apollo.planning.FemPosDeviationSmootherConfig.weight_ref_deviation', index=1,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_path_length', full_name='apollo.planning.FemPosDeviationSmootherConfig.weight_path_length', index=2,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apply_curvature_constraint', full_name='apollo.planning.FemPosDeviationSmootherConfig.apply_curvature_constraint', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_curvature_constraint_slack_var', full_name='apollo.planning.FemPosDeviationSmootherConfig.weight_curvature_constraint_slack_var', index=4,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(100),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curvature_constraint', full_name='apollo.planning.FemPosDeviationSmootherConfig.curvature_constraint', index=5,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_sqp', full_name='apollo.planning.FemPosDeviationSmootherConfig.use_sqp', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sqp_ftol', full_name='apollo.planning.FemPosDeviationSmootherConfig.sqp_ftol', index=7,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.0001),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sqp_ctol', full_name='apollo.planning.FemPosDeviationSmootherConfig.sqp_ctol', index=8,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.001),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sqp_pen_max_iter', full_name='apollo.planning.FemPosDeviationSmootherConfig.sqp_pen_max_iter', index=9,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sqp_sub_max_iter', full_name='apollo.planning.FemPosDeviationSmootherConfig.sqp_sub_max_iter', index=10,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=100,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_iter', full_name='apollo.planning.FemPosDeviationSmootherConfig.max_iter', index=11,
      number=100, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=500,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_limit', full_name='apollo.planning.FemPosDeviationSmootherConfig.time_limit', index=12,
      number=101, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='verbose', full_name='apollo.planning.FemPosDeviationSmootherConfig.verbose', index=13,
      number=102, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scaled_termination', full_name='apollo.planning.FemPosDeviationSmootherConfig.scaled_termination', index=14,
      number=103, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warm_start', full_name='apollo.planning.FemPosDeviationSmootherConfig.warm_start', index=15,
      number=104, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='print_level', full_name='apollo.planning.FemPosDeviationSmootherConfig.print_level', index=16,
      number=200, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_num_of_iterations', full_name='apollo.planning.FemPosDeviationSmootherConfig.max_num_of_iterations', index=17,
      number=201, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=500,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceptable_num_of_iterations', full_name='apollo.planning.FemPosDeviationSmootherConfig.acceptable_num_of_iterations', index=18,
      number=202, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=15,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tol', full_name='apollo.planning.FemPosDeviationSmootherConfig.tol', index=19,
      number=203, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1e-08),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceptable_tol', full_name='apollo.planning.FemPosDeviationSmootherConfig.acceptable_tol', index=20,
      number=204, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=783,
)

DESCRIPTOR.message_types_by_name['FemPosDeviationSmootherConfig'] = _FEMPOSDEVIATIONSMOOTHERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FemPosDeviationSmootherConfig = _reflection.GeneratedProtocolMessageType('FemPosDeviationSmootherConfig', (_message.Message,), {
  'DESCRIPTOR' : _FEMPOSDEVIATIONSMOOTHERCONFIG,
  '__module__' : 'modules.planning.proto.math.fem_pos_deviation_smoother_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.FemPosDeviationSmootherConfig)
  })
_sym_db.RegisterMessage(FemPosDeviationSmootherConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/camera/app/proto/perception.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/camera/app/proto/perception.proto',
  package='apollo.perception.camera.app',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4modules/perception/camera/app/proto/perception.proto\x12\x1c\x61pollo.perception.camera.app\"B\n\x0bPluginParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08root_dir\x18\x02 \x01(\t\x12\x13\n\x0b\x63onfig_file\x18\x03 \x01(\t\"e\n\rDetectorParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\x12\x13\n\x0b\x63\x61mera_name\x18\x02 \x01(\t\"O\n\x0cTrackerParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"S\n\x10TransformerParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"U\n\x12PostprocessorParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"O\n\x0c\x46\x65\x61tureParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"\xd0\x01\n\nDebugParam\x12\x19\n\x11\x64\x65tection_out_dir\x18\x01 \x01(\t\x12!\n\x19tracked_detection_out_dir\x18\x02 \x01(\t\x12\x16\n\x0etrack_out_file\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65tect_feature_dir\x18\x04 \x01(\t\x12\x14\n\x0clane_out_dir\x18\x05 \x01(\t\x12\x1d\n\x15\x63\x61mera2world_out_file\x18\x06 \x01(\t\x12\x1b\n\x13\x63\x61libration_out_dir\x18\x07 \x01(\t\"\x83\x02\n\x13LanePerceptionParam\x12H\n\x13lane_detector_param\x18\x01 \x01(\x0b\x32+.apollo.perception.camera.app.DetectorParam\x12K\n\x18lane_postprocessor_param\x18\x02 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\x12\x45\n\x12lane_tracker_param\x18\x03 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\x12\x0e\n\x06gpu_id\x18\x04 \x01(\x05\"u\n\x17\x43\x61librationServiceParam\x12\x19\n\x11\x63\x61librator_method\x18\x02 \x01(\t\x12?\n\x0cplugin_param\x18\x03 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"V\n\x13ObjectTemplateParam\x12?\n\x0cplugin_param\x18\x01 \x01(\x0b\x32).apollo.perception.camera.app.PluginParam\"\xd3\x05\n\x0fPerceptionParam\x12\x43\n\x0e\x64\x65tector_param\x18\x01 \x03(\x0b\x32+.apollo.perception.camera.app.DetectorParam\x12\x41\n\rtracker_param\x18\x02 \x01(\x0b\x32*.apollo.perception.camera.app.TrackerParam\x12I\n\x11transformer_param\x18\x03 \x01(\x0b\x32..apollo.perception.camera.app.TransformerParam\x12M\n\x13postprocessor_param\x18\x04 \x01(\x0b\x32\x30.apollo.perception.camera.app.PostprocessorParam\x12\x0e\n\x06gpu_id\x18\x05 \x01(\x05\x12\x19\n\x11\x63\x61mera_intrinsics\x18\x06 \x01(\t\x12\x41\n\rfeature_param\x18\x07 \x01(\x0b\x32*.apollo.perception.camera.app.FeatureParam\x12\x45\n\nlane_param\x18\x08 \x03(\x0b\x32\x31.apollo.perception.camera.app.LanePerceptionParam\x12X\n\x19\x63\x61libration_service_param\x18\t \x01(\x0b\x32\x35.apollo.perception.camera.app.CalibrationServiceParam\x12=\n\x0b\x64\x65\x62ug_param\x18\n \x01(\x0b\x32(.apollo.perception.camera.app.DebugParam\x12P\n\x15object_template_param\x18\x0b \x01(\x0b\x32\x31.apollo.perception.camera.app.ObjectTemplateParam\"\xab\x01\n\x11TrafficLightParam\x12\x43\n\x0e\x64\x65tector_param\x18\x01 \x03(\x0b\x32+.apollo.perception.camera.app.DetectorParam\x12\x41\n\rtracker_param\x18\x02 \x01(\x0b\x32*.apollo.perception.camera.app.TrackerParam\x12\x0e\n\x06gpu_id\x18\x03 \x01(\x05'
)




_PLUGINPARAM = _descriptor.Descriptor(
  name='PluginParam',
  full_name='apollo.perception.camera.app.PluginParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.perception.camera.app.PluginParam.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root_dir', full_name='apollo.perception.camera.app.PluginParam.root_dir', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_file', full_name='apollo.perception.camera.app.PluginParam.config_file', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=152,
)


_DETECTORPARAM = _descriptor.Descriptor(
  name='DetectorParam',
  full_name='apollo.perception.camera.app.DetectorParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.DetectorParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_name', full_name='apollo.perception.camera.app.DetectorParam.camera_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=255,
)


_TRACKERPARAM = _descriptor.Descriptor(
  name='TrackerParam',
  full_name='apollo.perception.camera.app.TrackerParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.TrackerParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=336,
)


_TRANSFORMERPARAM = _descriptor.Descriptor(
  name='TransformerParam',
  full_name='apollo.perception.camera.app.TransformerParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.TransformerParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=421,
)


_POSTPROCESSORPARAM = _descriptor.Descriptor(
  name='PostprocessorParam',
  full_name='apollo.perception.camera.app.PostprocessorParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.PostprocessorParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=508,
)


_FEATUREPARAM = _descriptor.Descriptor(
  name='FeatureParam',
  full_name='apollo.perception.camera.app.FeatureParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.FeatureParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=510,
  serialized_end=589,
)


_DEBUGPARAM = _descriptor.Descriptor(
  name='DebugParam',
  full_name='apollo.perception.camera.app.DebugParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detection_out_dir', full_name='apollo.perception.camera.app.DebugParam.detection_out_dir', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracked_detection_out_dir', full_name='apollo.perception.camera.app.DebugParam.tracked_detection_out_dir', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='track_out_file', full_name='apollo.perception.camera.app.DebugParam.track_out_file', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detect_feature_dir', full_name='apollo.perception.camera.app.DebugParam.detect_feature_dir', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_out_dir', full_name='apollo.perception.camera.app.DebugParam.lane_out_dir', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera2world_out_file', full_name='apollo.perception.camera.app.DebugParam.camera2world_out_file', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_out_dir', full_name='apollo.perception.camera.app.DebugParam.calibration_out_dir', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=800,
)


_LANEPERCEPTIONPARAM = _descriptor.Descriptor(
  name='LanePerceptionParam',
  full_name='apollo.perception.camera.app.LanePerceptionParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane_detector_param', full_name='apollo.perception.camera.app.LanePerceptionParam.lane_detector_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_postprocessor_param', full_name='apollo.perception.camera.app.LanePerceptionParam.lane_postprocessor_param', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_tracker_param', full_name='apollo.perception.camera.app.LanePerceptionParam.lane_tracker_param', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_id', full_name='apollo.perception.camera.app.LanePerceptionParam.gpu_id', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=803,
  serialized_end=1062,
)


_CALIBRATIONSERVICEPARAM = _descriptor.Descriptor(
  name='CalibrationServiceParam',
  full_name='apollo.perception.camera.app.CalibrationServiceParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='calibrator_method', full_name='apollo.perception.camera.app.CalibrationServiceParam.calibrator_method', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.CalibrationServiceParam.plugin_param', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1064,
  serialized_end=1181,
)


_OBJECTTEMPLATEPARAM = _descriptor.Descriptor(
  name='ObjectTemplateParam',
  full_name='apollo.perception.camera.app.ObjectTemplateParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin_param', full_name='apollo.perception.camera.app.ObjectTemplateParam.plugin_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1183,
  serialized_end=1269,
)


_PERCEPTIONPARAM = _descriptor.Descriptor(
  name='PerceptionParam',
  full_name='apollo.perception.camera.app.PerceptionParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detector_param', full_name='apollo.perception.camera.app.PerceptionParam.detector_param', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracker_param', full_name='apollo.perception.camera.app.PerceptionParam.tracker_param', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transformer_param', full_name='apollo.perception.camera.app.PerceptionParam.transformer_param', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postprocessor_param', full_name='apollo.perception.camera.app.PerceptionParam.postprocessor_param', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_id', full_name='apollo.perception.camera.app.PerceptionParam.gpu_id', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='camera_intrinsics', full_name='apollo.perception.camera.app.PerceptionParam.camera_intrinsics', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_param', full_name='apollo.perception.camera.app.PerceptionParam.feature_param', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_param', full_name='apollo.perception.camera.app.PerceptionParam.lane_param', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calibration_service_param', full_name='apollo.perception.camera.app.PerceptionParam.calibration_service_param', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_param', full_name='apollo.perception.camera.app.PerceptionParam.debug_param', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_template_param', full_name='apollo.perception.camera.app.PerceptionParam.object_template_param', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1272,
  serialized_end=1995,
)


_TRAFFICLIGHTPARAM = _descriptor.Descriptor(
  name='TrafficLightParam',
  full_name='apollo.perception.camera.app.TrafficLightParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detector_param', full_name='apollo.perception.camera.app.TrafficLightParam.detector_param', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracker_param', full_name='apollo.perception.camera.app.TrafficLightParam.tracker_param', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_id', full_name='apollo.perception.camera.app.TrafficLightParam.gpu_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1998,
  serialized_end=2169,
)

_DETECTORPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_TRACKERPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_TRANSFORMERPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_POSTPROCESSORPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_FEATUREPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_LANEPERCEPTIONPARAM.fields_by_name['lane_detector_param'].message_type = _DETECTORPARAM
_LANEPERCEPTIONPARAM.fields_by_name['lane_postprocessor_param'].message_type = _PLUGINPARAM
_LANEPERCEPTIONPARAM.fields_by_name['lane_tracker_param'].message_type = _PLUGINPARAM
_CALIBRATIONSERVICEPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_OBJECTTEMPLATEPARAM.fields_by_name['plugin_param'].message_type = _PLUGINPARAM
_PERCEPTIONPARAM.fields_by_name['detector_param'].message_type = _DETECTORPARAM
_PERCEPTIONPARAM.fields_by_name['tracker_param'].message_type = _TRACKERPARAM
_PERCEPTIONPARAM.fields_by_name['transformer_param'].message_type = _TRANSFORMERPARAM
_PERCEPTIONPARAM.fields_by_name['postprocessor_param'].message_type = _POSTPROCESSORPARAM
_PERCEPTIONPARAM.fields_by_name['feature_param'].message_type = _FEATUREPARAM
_PERCEPTIONPARAM.fields_by_name['lane_param'].message_type = _LANEPERCEPTIONPARAM
_PERCEPTIONPARAM.fields_by_name['calibration_service_param'].message_type = _CALIBRATIONSERVICEPARAM
_PERCEPTIONPARAM.fields_by_name['debug_param'].message_type = _DEBUGPARAM
_PERCEPTIONPARAM.fields_by_name['object_template_param'].message_type = _OBJECTTEMPLATEPARAM
_TRAFFICLIGHTPARAM.fields_by_name['detector_param'].message_type = _DETECTORPARAM
_TRAFFICLIGHTPARAM.fields_by_name['tracker_param'].message_type = _TRACKERPARAM
DESCRIPTOR.message_types_by_name['PluginParam'] = _PLUGINPARAM
DESCRIPTOR.message_types_by_name['DetectorParam'] = _DETECTORPARAM
DESCRIPTOR.message_types_by_name['TrackerParam'] = _TRACKERPARAM
DESCRIPTOR.message_types_by_name['TransformerParam'] = _TRANSFORMERPARAM
DESCRIPTOR.message_types_by_name['PostprocessorParam'] = _POSTPROCESSORPARAM
DESCRIPTOR.message_types_by_name['FeatureParam'] = _FEATUREPARAM
DESCRIPTOR.message_types_by_name['DebugParam'] = _DEBUGPARAM
DESCRIPTOR.message_types_by_name['LanePerceptionParam'] = _LANEPERCEPTIONPARAM
DESCRIPTOR.message_types_by_name['CalibrationServiceParam'] = _CALIBRATIONSERVICEPARAM
DESCRIPTOR.message_types_by_name['ObjectTemplateParam'] = _OBJECTTEMPLATEPARAM
DESCRIPTOR.message_types_by_name['PerceptionParam'] = _PERCEPTIONPARAM
DESCRIPTOR.message_types_by_name['TrafficLightParam'] = _TRAFFICLIGHTPARAM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PluginParam = _reflection.GeneratedProtocolMessageType('PluginParam', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.PluginParam)
  })
_sym_db.RegisterMessage(PluginParam)

DetectorParam = _reflection.GeneratedProtocolMessageType('DetectorParam', (_message.Message,), {
  'DESCRIPTOR' : _DETECTORPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.DetectorParam)
  })
_sym_db.RegisterMessage(DetectorParam)

TrackerParam = _reflection.GeneratedProtocolMessageType('TrackerParam', (_message.Message,), {
  'DESCRIPTOR' : _TRACKERPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.TrackerParam)
  })
_sym_db.RegisterMessage(TrackerParam)

TransformerParam = _reflection.GeneratedProtocolMessageType('TransformerParam', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFORMERPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.TransformerParam)
  })
_sym_db.RegisterMessage(TransformerParam)

PostprocessorParam = _reflection.GeneratedProtocolMessageType('PostprocessorParam', (_message.Message,), {
  'DESCRIPTOR' : _POSTPROCESSORPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.PostprocessorParam)
  })
_sym_db.RegisterMessage(PostprocessorParam)

FeatureParam = _reflection.GeneratedProtocolMessageType('FeatureParam', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.FeatureParam)
  })
_sym_db.RegisterMessage(FeatureParam)

DebugParam = _reflection.GeneratedProtocolMessageType('DebugParam', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.DebugParam)
  })
_sym_db.RegisterMessage(DebugParam)

LanePerceptionParam = _reflection.GeneratedProtocolMessageType('LanePerceptionParam', (_message.Message,), {
  'DESCRIPTOR' : _LANEPERCEPTIONPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.LanePerceptionParam)
  })
_sym_db.RegisterMessage(LanePerceptionParam)

CalibrationServiceParam = _reflection.GeneratedProtocolMessageType('CalibrationServiceParam', (_message.Message,), {
  'DESCRIPTOR' : _CALIBRATIONSERVICEPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.CalibrationServiceParam)
  })
_sym_db.RegisterMessage(CalibrationServiceParam)

ObjectTemplateParam = _reflection.GeneratedProtocolMessageType('ObjectTemplateParam', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTTEMPLATEPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.ObjectTemplateParam)
  })
_sym_db.RegisterMessage(ObjectTemplateParam)

PerceptionParam = _reflection.GeneratedProtocolMessageType('PerceptionParam', (_message.Message,), {
  'DESCRIPTOR' : _PERCEPTIONPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.PerceptionParam)
  })
_sym_db.RegisterMessage(PerceptionParam)

TrafficLightParam = _reflection.GeneratedProtocolMessageType('TrafficLightParam', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHTPARAM,
  '__module__' : 'modules.perception.camera.app.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.app.TrafficLightParam)
  })
_sym_db.RegisterMessage(TrafficLightParam)


# @@protoc_insertion_point(module_scope)
